# OpenVela

## Objectives

## How to publish a new release

Change the version on `pyproject.toml`

Execute these commands when pushing from your local to the remote repo

```
git add .
git commit -m "Your message"
git tag -a TAG -m "Your message"
git push origin TAG
```